@@ -1,11 +1,11 @@
 from typing import Optional
 from pathlib import Path
 
-from .base import dumb_pipe, using_path, is_pipeline
-
-from play_sounds import play_after, DEFAULT_SOUND
+from play_sounds import play_after, bell_after, DEFAULT_SOUND
 import click
 
+from .base import dumb_pipe, using_path, is_pipeline
+
 
 ENV_VAR = 'DING'
 
@@ -21,10 +21,14 @@ def run(file: Optional[Path]):
 @click.command(help="Play specified sound after job is complete.")
 @click.option('-s', '--sound_path', required=False,
   type=click.Path(exists=True), help="Path to sound to play.")
+@click.option('-b', '--bell', required=False,
+  default=False, show_default=True, is_flag=True,
+  type=click.BOOL, help="Ring terminal bell, as well.")
 @click.option('-w', '--warn', required=False,
   is_flag=True, default=False, help="Show warnings.")
-def cmd(sound_path: Optional[str], warn: bool):
-  with using_path(sound_path, warn, DEFAULT_SOUND, ENV_VAR) as path:
+def cmd(sound_path: Optional[str], bell: bool, warn: bool):
+  with bell_after(bell), \
+    using_path(sound_path, warn, DEFAULT_SOUND, ENV_VAR) as path:
     run(path)
 
 
