@@ -3,7 +3,6 @@ from typing import Optional, ContextManager
 from sys import stdin, stdout, stderr, exit
 from pathlib import Path
 from os import environ
-#from subprocess import run
 
 from play_sounds import DEFAULT_SONG
 
@@ -15,15 +14,17 @@ ENV_VAR = 'ONHOLD'
 KB = 2 ** 10
 CHUNK = 64 * KB
 
+BELL_CMD = "tput bel"
+
 
 def is_pipeline() -> bool:
   return not stdin.isatty()
 
 
 # python 3.8+ compatible
-#def dumb_pipe():
-#  while data := stdin.buffer.read(CHUNK):
-#    stdout.buffer.write(data)
+# def dumb_pipe():
+#   while data := stdin.buffer.read(CHUNK):
+#     stdout.buffer.write(data)
 
 
 # python 3.6 compatible
@@ -37,7 +38,6 @@ def dumb_pipe():
     stdout.buffer.write(data)
 
 
-
 @contextmanager
 def using_path(
   sound_path: Optional[str],
@@ -50,6 +50,9 @@ def using_path(
   if sound_path:
     path = Path(str(sound_path))
 
+#   elif var := environ.get(env_var):
+#     path = Path(var)
+
   elif env_var in environ:
     path = Path(environ[env_var])
 
